require_relative '../spec_helper'

describe Pokan::Cluster::Configuration do

  let(:yaml) {
    <<-END
      connection:
        udp: 8888
        tcp: 8888

      seed:
        address: "10.10.10.8"
        redis: 6379

      log:
        enabled: true
        log_file: "/var/log/pokan" 
    END
  }

  subject { 
    parser = double('parser')
    parser.stub! :parse => YAML.load(yaml)
    Pokan::Cluster::Configuration.new(yaml, parser) 
  }

  it 'should retrieve all data' do
    subject.get('connection.udp').should eq 8888
    subject.get('connection.tcp').should eq 8888

    subject.get('seed.address').should eq "10.10.10.8"
    subject.get('seed.redis').should eq 6379

    subject.get('log.enabled').should be_true
    subject.get('log.log_file').should eq "/var/log/pokan"
  end

  it 'should return nil on non existent configuration' do
    subject.get('log.levell').should be_nil
  end



end
