require_relative 'spec_helper'

describe Pokan::Cluster do

  subject { 
    class MyPokan
      include Pokan::Cluster

      config {
        YAML.parse(<<-END
          pokan:

            address: "10.10.10.7" 

            connect:
              tcp: 8888
              udp: 8888
              epoll: true

            seed:
              address: "10.10.10.1"
              redis: 6379
            
            gossip:
              every: 2
              share: "cpu,memory"

            log:
              enabled: true
              level: "info"
              file: "pokan.log"
        END
        ).to_ruby
      }

      self
    end
  }

  context 'when all options are passed' do

    it 'should properly initialize instance variables' do
      subject.address.should eq '10.10.10.7'
      
      subject.tcp_port.should eq 8888
      subject.udp_port.should eq 8888
      subject.epoll.should be_true

      subject.seed.should eq '10.10.10.1'

      subject.gossip_interval.should eq 2
      subject.shares.should eq ['cpu', 'memory']

      subject.logging.should be_true
      subject.log_level.should eq :info
      subject.log_file.should eq 'pokan.log'

    end

    it 'should delegate to the server instance' do
      subject.use_epoll.should be_true
    end

  end

end
